#!/bin/csh

if (`flagLoc $argv -help`) then
   echo "Apply Compensation for Digital Oversampling:"
   echo " -in  inName  [test.fid]  Input Time-Domain Data."
   echo " -out outName [df.fid]    Output Time-Domain Data."
   echo " -df  dfVal   [0.0]       Oversampling Parameter (Group Delay)." 
   exit 0
endif

set inName  = (`getArgD $argv -in  test.fid`)
set outName = (`getArgD $argv -out df.fid`)
set dfVal   = (`getArgD $argv -df  0.0`)

#
# No adjustment:
# Copy input to output if processing is not in-place.

if (`IMATH "$dfVal == 0.0"`) then
   if (`string same $inName $outName`) then
      exit 0
   else
      /bin/cp $inName $outName
      exit 0
   endif
endif

#
# Since the correction changes the size, it can't be done in-place.

if (`IMATH "$dfVal != integer($dfVal)"`) then
   nmrPrintf -stderr "applyDF.com Warning: only integer GRPDLY is supported ($dfVal).\n" 
endif

set tmpName = tmp_df_$$.dat

/bin/rm -f $tmpName

set dfValFinal = (`IMATH "integer($dfVal)"`)

set xT    = (`getParm -in $inName -parm NDSIZE -dim CUR_XDIM -fmt %.0f`)
set xTNew = (`IMATH "$xT - $dfValFinal"`)

if (`flagLoc $argv -verb`) then
   echo "      Applying oversampling correction, $dfValFinal points ($dfVal) ..."
endif

nmrPipe -in $inName -fn MAC -macro $NMRTXT/applyDF.M -var dfVal $dfValFinal -out $tmpName -ov

/bin/rm -f $outName

nmrPipe -in $tmpName -fn EXT -xn $xTNew -sw -out $outName -ov

/bin/rm -f $tmpName

exit 0
