#!/bin/sh
# The next line restarts using nmrWish \
exec nmrWish "$0" -- "$@"

set auto_path    "[split $env(TCLPATH) :] $auto_path"
set ARGV         [concat $argv0 $argv]
set ARGC         [llength $ARGV]

set menuName None

if {[info exists env(NMRTXT)]} {set menuName $env(NMRTXT)/proc.tab}
   
set cmndPrefix "nmrTerm -e csh"
set fileName   nmr_info.txt
set txtWide    100
set txtHigh    32

set title    "Information"
set mode     info 
set bgColor  yellow
set fgColor  black
set waitFlag 0

if {[flagLoc $ARGV -help]} \
   {
    puts "Utility for NMRDraw Text Windows:"
    puts " -file  fileName \[nmr_init.tab\]     Input Text File to Display."
    puts " -menu  menuName \[\$NMRTXT/proc.tar\] Processing Menu Input."
    puts " -wide  wide     \[32\]               Text Edit Window Height, Characters." 
    puts " -high  high     \[100\]              Text Edit Window Width, Characters." 
    puts "Display Mode:"
    puts " -info           Show Informational Text."
    puts " -proc           Show Processing Script."
    puts " -helptext       Show Help Text."
    exit 0
   }

if {[flagLoc $ARGV -helptext]} \
   {
    set title    "NMRPipe Help Text"
    set fileName nmr_help.txt
    set bgColor  green
    set mode     help
   }

if {[flagLoc $ARGV -proc]} \
   {
    set title    "NMRPipe Processing Script"
    set fileName nmrproc.com
    set bgColor  cyan
    set mode     proc 
   }

getArgD $ARGV -file fileName
getArgD $ARGV -menu menuName
getArgD $ARGV -wide txtWide
getArgD $ARGV -high txtHigh
getArgD $ARGV -bg   bgColor
getArgD $ARGV -fg   fgColor

proc exitProc {} \
{
   exit 0
}

proc execScript {} \
{
   global fileName cmndPrefix waitFlag

   if {$waitFlag} \
      {
       catch "exec $cmndPrefix $fileName"
      } \
   else \
      {
       catch "exec $cmndPrefix $fileName &"
      }
}

proc killScript {} \
{
   global fileName

   catch "exec killShell $fileName"
}

proc readText { } \
{
   global fileName
   
   readThisFile $fileName
}

proc readThisFile { thisName } \
{
   if {![file exists $thisName]} {return 1}

   set error [catch {set inUnit [open $thisName r]}]
   if {$error} {return $error}

   while {[gets $inUnit line] >= 0} {.textFrame.scriptText insert end "${line}\n"}

   catch "close $inUnit"
}

proc writeThisFile {} \
{
   global fileName
}

proc setFileName {} \
{
   global fileName

   set types \
      {
       { {All Files}  *      }
       { {ser}        {ser*} }
       { {fid}        {fid*} }
       { {dat}        {.dat .DAT} }
       { {jdf}        {.jdf .JDF} }
       { {seq}        {.seq} }
       { {Text}       {.txt} }
       { {TCL}        {.tcl} }
       { {C-Shell}    {.com .csh} }
       { {K-Shell}    {.ksh} }
       { {Shell}      {.sh}  }
      }

   set oldName $fileName

   set fileName [tk_getOpenFile -title "File Name" -filetypes $types]

   if {![llength $fileName]} \
      {
       set fileName $oldName
       return
      }
}

proc clearText {} \
{
   .textFrame.scriptText delete 1.0 end
   update
}

proc saveFile {} \
{
   global mode fileName

   set lineCount 0

   if {[file exists $fileName]} \
      {
       if {![okWrite $fileName]} {return $lineCount}
      } 

   if {![strcasecmp $mode proc]} \
      {
       set error [catch {set outUnit [open $fileName w 0744]}]
      } \
   else \
      {
       set error [catch {set outUnit [open $fileName w]}]
      }

   scan [.textFrame.scriptText index end] %d lineCount

   for {set i 1} {$i < $lineCount} {incr i} \
      {
       .textFrame.scriptText mark set first $i.0
       set  str [.textFrame.scriptText get  first "first lineend"]
       puts $outUnit $str
      }

   close $outUnit

   tk_dialog .saveDialog Save "Saved $lineCount lines in file $fileName" info 0 Continue

   return $lineCount
}

proc insertScripts args \
{
   global env textInfo

   set thisArgv [concat insertScripts $args]

   set scriptList ""
   set helpList   ""

   getArgD $thisArgv -script scriptList
   getArgD $thisArgv -help   helpList

   foreach item $scriptList \
      {
       if {![info exists textInfo($item)]} continue

       set s [lindex $textInfo($item) 0]
       set c [string index $s 0]

       if {![strcmp $c "@"]} \
          {
           set thisName [string range [string trim $textInfo($item)] 1 end]
           readThisFile $env(NMRTXT)/$thisName
          } \
       else \
          {
           .textFrame.scriptText insert end "$textInfo($item)\n"
          }
      }
}

proc addMenuItems {} \
{
   global menuName menuInfo textInfo

   if {![file exists $menuName]} {return 0}
   
   set status [getTextLines $menuName menuInfo]
   if {$status < 0} {return 0}

   set thisTitle None
   set textCount 0
   set itemCount 0

   for {set i 0} {$i < $menuInfo(lineCount)} {incr i} \
      {
       set s [lindex $menuInfo($i) 0]
       set c [string index $s 0]

       if {![strcmp $c ">"]} \
          {
           set thisTitle [string range [string trim $menuInfo($i)] 1 end]
           set thisState script
           set itemCount 0

           for {incr i} {$i < $menuInfo(lineCount)} {incr i} \
              {
               set s [lindex $menuInfo($i) 0]
               set c [string index $s 0]

               if {![strcmp $c "#"]} \
                  {
                   incr itemCount

                   set itemInfo($itemCount,title)      [string range [string trim $menuInfo($i)] 1 end]
                   set itemInfo($itemCount,scriptList) ""
                   set itemInfo($itemCount,helpList)   ""

                   set thisState script
                  } \
               elseif {![strcmp $c "?"]} \
                  {
                   set thisState help
                  } \
               elseif {![strcmp $c "@"]} \
                  {
                   incr textCount

                   set textInfo($textCount) [string trim $menuInfo($i)]

                   if {![strcasecmp $thisState script]} \
                      {
                       lappend itemInfo($itemCount,scriptList) $textCount
                      } \
                   else \
                      {
                       lappend itemInfo($itemCount,helpList)   $textCount
                      }
                  } \
               elseif {![strcmp $c "<"]} \
                  {
                   break
                  } \
               else \
                  {
                   if {![strcasecmp $thisState script]} \
                      {
                       incr textCount

                       set textInfo($textCount) [string trim $menuInfo($i)]

                       lappend itemInfo($itemCount,scriptList) $textCount
                      }
                  }
              }

#          puts "Menu Button $thisTitle $itemCount menu items"

           if {$itemCount == 1} \
              {
               button .menuFrame.button$i -width 26 -relief groove -text $thisTitle -anchor w
               pack   .menuFrame.button$i -in .menuFrame -side top
              } \
           else \
              {
               menubutton .menuFrame.button$i -menu .menuFrame.button$i.menu -width 24 -relief groove \
                          -text "$thisTitle" -anchor w -indicatoron 1

               menu .menuFrame.button$i.menu -tearoff False

               for {set j 1} {$j <= $itemCount} {incr j} \
                  {
                   .menuFrame.button$i.menu add command -label $itemInfo($j,title) \
                    -command "insertScripts -script $itemInfo($j,scriptList) -help $itemInfo($j,helpList)"
 
#                  puts "Menu Item $j: $itemInfo($j,title)"
#                  puts " text: $itemInfo($j,scriptList)"
#                  puts " help: $itemInfo($j,helpList)"
                  }

               pack  .menuFrame.button$i -in .menuFrame -side top
              }
          }
      }
}

wm geom  . +100+100
wm title . "$title $fileName"

set menuInfo(inName) $menuName

frame .cmndFrame
frame .topFrame
frame .botFrame
frame .scriptFrame
frame .menuFrame 
frame .textFrame
frame .spaceFrame1 -height 6
frame .spaceFrame2 -height 4
frame .lineFrame1  -height 1 -bg black 

pack .cmndFrame   -in . -side top  -expand 0 -fill x
pack .scriptFrame -in . -side top  -expand 1 -fill both

pack .topFrame  .botFrame  .spaceFrame1 .lineFrame1 .spaceFrame2 -in .cmndFrame -side top  -expand 1 -fill x -anchor w
pack .menuFrame .textFrame -in .scriptFrame -side left -expand 1 -fill both 

if {![strcasecmp $mode proc]} \
   {
    button .topFrame.save  -text "Save"    -command saveFile   -relief groove 
    button .topFrame.exec  -text "Execute" -command execScript -relief groove 
    button .topFrame.kill  -text "Kill"    -command killScript -relief groove 
    button .topFrame.read  -text "Insert"  -command readText   -relief groove 
    button .topFrame.clear -text "Clear"   -command clearText  -relief groove 
    button .topFrame.done  -text "Done"    -command exitProc   -relief groove 

    pack .topFrame.save .topFrame.exec .topFrame.kill .topFrame.read .topFrame.clear -in .topFrame -side left -padx 4 -pady 4
    pack .topFrame.done -in .topFrame -side right -padx 4 -pady 4
   } \
else \
   {
    button .topFrame.save  -text "Save"    -command saveFile  -relief groove
    button .topFrame.clear -text "Clear"   -command clearText -relief groove
    button .topFrame.done  -text "Done"    -command exitProc  -relief groove

    pack .topFrame.save .topFrame.clear -in .topFrame -side left -padx 4 -pady 4
    pack .topFrame.done -in .topFrame -side right -padx 4 -pady 4
   }

if {![strcasecmp $mode proc]} \
   {
    label  .botFrame.prefixLab   -text "Command Prefix:"
    entry  .botFrame.prefixEntry -textvariable cmndPrefix -width 23 

    label  .botFrame.macroLab   -text "   Macro Name:"
    entry  .botFrame.macroEntry -textvariable fileName    -width 23 

    button .botFrame.fileButton -command setFileName -relief raised -bitmap @$env(NMRTXT)/caret.map -fg blue 

    label  .botFrame.waitLab    -text "   Wait:"

    radiobutton .botFrame.waitYes -variable waitFlag -value 1 -text "Yes"
    radiobutton .botFrame.waitNo  -variable waitFlag -value 0 -text "No"

    pack .botFrame.prefixLab .botFrame.prefixEntry  .botFrame.macroLab .botFrame.macroEntry \
         .botFrame.fileButton .botFrame.waitLab .botFrame.waitYes .botFrame.waitNo -in .botFrame -side left

    addMenuItems
}

text .textFrame.scriptText -yscrollcommand ".textFrame.scrollY set" \
      -height $txtHigh -width $txtWide -relief sunken -borderwidth 3   \
      -background $bgColor

scrollbar .textFrame.scrollY -command ".textFrame.scriptText yview" -relief sunken

pack .textFrame.scrollY    -in .textFrame -side right -fill y -expand 1
pack .textFrame.scriptText -in .textFrame -side left -padx 1m -pady 1m -fill y -expand 1

readThisFile $fileName
