#!/bin/csh

if (`flagLoc $argv -help`) then
   echo "Normalization of Spectral Series Listed in a Metadata Table."
   echo "Version 2025.071.20.32"
   echo " -meta    metaName [meta.tab]     Metadata Table (INDEX DIR_NAME TITLE)."
   echo " -ftName  ftName   [Auto]         Name of Processed Spectrum In Its Original Directory."
   echo " -ftDir   ftDir    [ft]           Directory of Processed Spectra, or Keyword None."
   echo " -srcDir  srcDir   [.]            Source Directory."
   echo "Normalization Command; Should be Last on Command-Line:"
   echo " -cmnd    normCmnd [Auto]         Normalization Command (Auto for rescale.com ...)."
   echo "Notes:"
   echo "  1. The normalization command should accept -in and -out arguments, and allow"
   echo "     in-place normalization."
   echo "  2. If the -ftDir option is used, the spectra in this directory will also be normalized."
   echo ""
   exit 0
endif

set normCmnd = "Auto"
set loc      = (`flagLoc $argv -cmnd`)
set thisArgv = ($argv)

if ($loc >= 1) then
   @ locP = $loc - 1
   @ locN = $loc + 1

   set normCmnd  = ($argv[$locN-])
   set thisArgv  = ($argv[1-$locP])
endif

set srcDir     = (`getArgD $thisArgv -srcDir  .`)
set ftDir      = (`getArgD $thisArgv -ftDir   ft`)
set ftName     = (`getArgD $thisArgv -ftName  Auto`)
set tabName    = (`getArgD $thisArgv -meta    meta.tab`)

#
#----------------------------------------------------------------------------------

set origDir = (`pwd`)

cd $srcDir
   set srcDirFull = (`pwd`)
cd $origDir

if (`string csame $ftDir None`) then
   set ftDirFull = None
else
   cd $ftDir
      set ftDirFull = (`pwd`)
   cd $origDir
endif

set idList   = (`getTabCol.tcl -in $tabName -var INDEX`)
set dirList  = (`getTabCol.tcl -in $tabName -var DIR_NAME`)
set titList  = (`getTabCol.tcl -in $tabName -var TITLE`)

@ dimCount = 2

if (`string csame $ftName Auto`) then
   if (-e $srcDir/$dirList[1]/test.ft2) then
      set thisName = $srcDir/$dirList[1]/test.ft2
      set ftName   = test.ft2
   else
      set thisName = $srcDir/$dirList[1]/test.ft1
      set ftName   = test.ft1
      @ dimCount   = 1
   endif 
else
   set thisName = $srcDir/$dirList[1]/$ftName
endif

set thisExt = ft$dimCount

if (`string csame $normCmnd Auto`) then
   set normCmnd = "rescale.com"
endif

echo ""

@ eCount = 0
@ i = 0

foreach d ($dirList)
   @ i++

   if (!(-d $srcDirFull/$d)) then
      echo "Normalization Error Finding Input Directory $srcDirFull/$d"
      @ eCount++
      continue
   endif

   cd $srcDirFull/$d
      set thisDir   = (`pwd`)
      set thisTitle = (`nmrPrintf "%03d-%s" $idList[$i] $titList[$i]`)

      if (!(-e $ftName)) then
         echo "Normalization Error Finding Spectrum Input $srcDirFull/$d/$ftName"
         @ eCount++
         continue
      endif

      if (`string notcsame $ftDir None`) then
         set outName = $ftDirFull/${thisTitle}.${thisExt}
      endif

      echo "Normalizing Spectrum $i of $#idList"':'
      echo " Input Directory:  $thisDir"
      echo " Title:            $thisTitle"

      set normList = ($ftName)

      if (`string notcsame $ftDir None`) then
         set thisName = $ftDirFull/${thisTitle}.${thisExt}

         if (-e $thisName) then
            set normList = ($normList $thisName)
         else
            echo "Normalization Error Finding Spectrum Input $thisName"
            @ eCount++
         endif
      endif

      foreach normName ($normList)
         echo " File:             $normName"
         $normCmnd -in $normName -out $normName
      end

   cd $origDir
end

if ($eCount != 0) then
   echo "Normalization Notice: Errors Occurred."
   exit 1
endif

exit 0
