#!/bin/sh
# The next line restarts using nmrWish \
exec nmrWish "$0" -notk -- "$@"

set auto_path    "[split $env(TCLPATH) :] $auto_path"
set ARGV         [concat $argv0 $argv]
set ARGC         [llength $ARGV]

if {[flagLoc $ARGV -help]} \
   {
    puts "Split a Table Into a Series of Single Line Tables:"
    puts " -in       inName    \[test.tab\]  Input Table." 
    puts " -outDir   outDir    \[tab\]       Output Directory."
    puts " -outName  outName   \[%04d.tab\]  Output Template."
    puts " -verb                           Verbose Mode ON."
    exit 0
   }

set inName     test.tab
set outDir     tab 
set outName    %04d.tab
set verbose    0

getArgD $ARGV -in        inName
getArgD $ARGV -outDir    outDir
getArgD $ARGV -outName   outName

if {[flagLoc $ARGV -verb]}   {set verbose 1}
if {[flagLoc $ARGV -boverb]} {set verbose 0}

if {![file exists $inName]} \
   {
    puts "SplitTab. Error Finding Input Table $inName"
    exit 1
   }

catch "file delete -force $outDir"
catch "file mkdir $outDir"

set t          [gdbRead table -in $inName]
set eList      [gdbGetInfo $t -parms entries]
set entryCount [llength $eList]

for {set i 0} {$i < $entryCount} {incr i} \
   {
    set thisName [format "%s/$outName" $outDir [expr $i + 1]]

    if {$verbose} {puts stderr "Entry [expr $i + 1] of $entryCount ($thisName)"}

    exec selectTab.tcl -in $inName -out $thisName -hdr -cond "_entry == $i"
   }

exit 0
